(()=>{var e={};const o={};function d(n){const t=o[n];if(void 0!==t)return t.exports;const s=o[n]={id:n,exports:{}};return e[n].call(s.exports,s,s.exports,d),s.exports}d.m=e,d.n=e=>{const o=e&&e.__esModule?()=>e.default:()=>e;return d.d(o,{a:o}),o},d.d=(e,o)=>{if(Array.isArray(o))for(var n=0;n<o.length;){var t=o[n++],s=o[n++];d.o(e,t)?0===s&&n++:0===s?Object.defineProperty(e,t,{enumerable:!0,value:o[n++]}):Object.defineProperty(e,t,{enumerable:!0,get:s})}else for(var t in o)d.o(o,t)&&!d.o(e,t)&&Object.defineProperty(e,t,{enumerable:!0,get:o[t]})},d.f={},d.e=e=>Promise.all(Object.keys(d.f).reduce((o,n)=>(d.f[n](e,o),o),[])),d.u=e=>"notes-"+e+".js?v="+{"vendors-node_modules_nextcloud_vue_dist_chunks_NcActionLink-BFiaYt9A_mjs-node_modules_nextclo-2f6d40":"76923dcee79fcc4de98d","vendors-node_modules_vue-material-design-icons_Plus_vue-node_modules_vue_dist_vue_runtime_esm-982c6f":"1770e329c73257558a24","dashboard-lazy":"f3fa0ae7595a81b24963","vendors-node_modules_nextcloud_dialogs_dist_chunks__plugin-vue_export-helper_mjs-node_modules-2cea7f":"50a2369dd449e8767801","vendors-node_modules_mdi_js_mdi_js-node_modules_nextcloud_dialogs_dist_chunks_preview_mjs-nod-24702c":"f8aaa1cc5574b5bd8759","vendors-node_modules_nextcloud_dialogs_dist_chunks_ConflictPicker_mjs":"f8941552bc00ba3bf875","vendors-node_modules_nextcloud_vue_dist_chunks_NcSelect--kERLlBK_mjs":"af78b5191b3432343d62","vendors-node_modules_nextcloud_vue_dist_components_NcTextField_index_mjs":"39b08511ffdf26833172","vendors-node_modules_nextcloud_dialogs_dist_chunks_FilePicker_mjs-node_modules_nextcloud_vue_-65a164":"71ee63adf7b38f68c593",node_modules_nextcloud_dialogs_dist_chunks_PublicAuthPrompt_mjs:"0d619ae6ebd3d7a98948","vendors-node_modules_nextcloud_vue_dist_components_NcColorPicker_index_mjs":"45ca4705738a881d4e41","vendors-node_modules_nextcloud_vue_dist_components_NcDateTimePicker_index_mjs":"1c71d066ae4c25f09885",node_modules_nextcloud_vue_dist_components_NcSelect_index_mjs:"b8f56f1e15a7bc9098ce"}[e],d.g=function(){if("object"==typeof globalThis)return globalThis;try{return this||new Function("return this")()}catch(e){if("object"==typeof window)return window}}(),d.o=(e,o)=>Object.prototype.hasOwnProperty.call(e,o),(()=>{const e={},o="notes:";d.l=(n,t,s,_)=>{if(e[n])return void e[n].push(t);let r,u;if(void 0!==s){const e=document.getElementsByTagName("script");for(var c=0;c<e.length;c++){const t=e[c];if(t.getAttribute("src")==n||t.getAttribute("data-webpack")==o+s){r=t;break}}}r||(u=!0,r=document.createElement("script"),r.charset="utf-8",d.nc&&r.setAttribute("nonce",d.nc),r.setAttribute("data-webpack",o+s),r.src=n),e[n]=[t];const i=(o,t)=>{r.onerror=r.onload=null,clearTimeout(l);const d=e[n];if(delete e[n],r.parentNode?.removeChild(r),d?.forEach(e=>e(t)),o)return o(t)},l=setTimeout(i.bind(null,void 0,{type:"timeout",target:r}),12e4);r.onerror=i.bind(null,r.onerror),r.onload=i.bind(null,r.onload),u&&document.head.appendChild(r)}})(),d.r=e=>{Symbol.toStringTag&&Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(e,"__esModule",{value:!0})},d.dn=e=>{(Object.getOwnPropertyDescriptor(e,"name")||{}).writable||Object.defineProperty(e,"name",{value:"default",configurable:!0})},d.p="/apps/notes/js/",(()=>{const e={dashboard:0};d.f.j=(o,n)=>{let t=d.o(e,o)?e[o]:void 0;if(0!==t)if(t)n.push(t[2]);else{const s=new Promise((n,d)=>t=e[o]=[n,d]);n.push(t[2]=s);const _=d.p+d.u(o),r=new Error,u=n=>{if(d.o(e,o)&&(t=e[o],0!==t&&(e[o]=void 0),t)){const e=n&&("load"===n.type?"missing":n.type),d=n&&n.target&&n.target.src;r.message="Loading chunk "+o+" failed.\n("+e+": "+d+")",r.name="ChunkLoadError",r.type=e,r.request=d,t[1](r)}};d.l(_,u,"chunk-"+o,o)}};const o=(o,n)=>{let[t,s,_]=n;var r,u,c=0;if(t.some(o=>0!==e[o])){for(r in s)d.o(s,r)&&(d.m[r]=s[r]);if(_)_(d)}for(o&&o(n);c<t.length;c++)u=t[c],d.o(e,u)&&e[u]&&e[u][0](),e[u]=0},n=self.webpackChunknotes=self.webpackChunknotes||[];n.forEach(o.bind(null,0)),n.push=o.bind(null,n.push.bind(n))})(),d.nc=void 0,d.nc=btoa(OC.requestToken),d.p=OC.linkTo("notes","js/"),document.addEventListener("DOMContentLoaded",()=>{OCA.Dashboard.register("notes",async e=>{const{createApp:o}=await Promise.all([d.e("vendors-node_modules_nextcloud_vue_dist_chunks_NcActionLink-BFiaYt9A_mjs-node_modules_nextclo-2f6d40"),d.e("vendors-node_modules_vue-material-design-icons_Plus_vue-node_modules_vue_dist_vue_runtime_esm-982c6f"),d.e("dashboard-lazy")]).then(d.bind(d,8756)),{default:s}=await Promise.all([d.e("vendors-node_modules_nextcloud_vue_dist_chunks_NcActionLink-BFiaYt9A_mjs-node_modules_nextclo-2f6d40"),d.e("vendors-node_modules_vue-material-design-icons_Plus_vue-node_modules_vue_dist_vue_runtime_esm-982c6f"),d.e("dashboard-lazy")]).then(d.bind(d,655)),_=o(s);_.mixin({methods:{t,n}}),_.mount(e)})})})();
//# sourceMappingURL=notes-dashboard.js.map?v=6ed6c293267ace2a7966