"use strict";(self.webpackChunknotes=self.webpackChunknotes||[]).push([["node_modules_nextcloud_vue_dist_components_NcSelect_index_mjs"],{3710(e,s,n){n.r(s),n.d(s,{default:()=>t.N});var t=n(9329)}}]);