OC.L10N.register(
    "notes",
    {
    "Notes" : "Anteckningar",
    "Create new note" : "Skapa ny anteckning",
    "More notes" : "Fler anteckningar",
    "Reading notes from filesystem has failed." : "Det gick inte att läsa anteckningar från filsystemet.",
    "Error" : "Fel",
    "New note" : "Ny anteckning",
    "Distraction-free notes and writing" : "Ostört antecknande och skrivande",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into apps ([Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios), as well as [3rd-party apps](https://github.com/nextcloud/notes/wiki#3rd-party-clients) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "Appen Anteckningar är en störningsfri anteckningsapp för [Nextcloud](https://www.nextcloud.com/). Den erbjuder kategorier för bättre organisering och har stöd för formatering med [Markdown](https://en.wikipedia.org/wiki/Markdown)-syntax. Anteckningarna sparas som filer i Nextcloud, så att du kan visa och redigera dem med alla Nextcloud-klienter. Dessutom möjliggör ett separat [REST-API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) enkel integrering i appar ([Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios) och [appar från tredje part](https://github.com/nextcloud/notes/wiki#3rd-party-clients), som ger smidig åtkomst till dina Nextcloud-anteckningar). Andra funktioner omfattar möjligheten att markera anteckningar som favoriter.",
    "Share" : "Dela",
    "Deleted {title}" : "{title} har tagits bort",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["Tog bort {number} anteckning","Tog bort {number} anteckningar"],
    "Undo Delete" : "Ångra radering",
    "Note recovered" : "Anteckningen återställdes",
    "_Recovered {number} note_::_Recovered {number} notes_" : ["Återställde {number} anteckning","Återställde {number} anteckningar"],
    "There are unsaved notes. Leaving the page will discard all changes!" : "Det finns osparade anteckningar. Om du lämnar sidan går alla ändringar förlorade!",
    "New category" : "Ny kategori",
    "Notes settings" : "Anteckningsinställningar",
    "Please see Nextcloud server log for details." : "Mer information finns i Nextclouds serverlogg.",
    "Custom" : "Anpassad",
    "Rich text" : "Formaterad text",
    "Plain text" : "Oformaterad text",
    "Preview" : "Förhandsgranskning",
    "Make the selection bold" : "Gör markeringen fetstil",
    "Make the selection italic" : "Gör markeringen kursiv",
    "Wrap the selection in quotes" : "Sätt markeringen inom citattecken",
    "The selection will be turned into monospace" : "Markeringen får fast teckenbredd",
    "Remove any styles from the selected text" : "Ta bort all formatering från den markerade texten",
    "Makes the current line a list element" : "Gör den aktuella raden till en listpunkt",
    "Makes the current line a list element with a number" : "Gör den aktuella raden till en numrerad listpunkt",
    "Toggle heading for current line" : "Växla rubrik för aktuell rad",
    "Set the current line as a big heading" : "Gör den aktuella raden till en stor rubrik",
    "Insert link" : "Infoga länk",
    "Insert image" : "Infoga bild",
    "Switch between editor and viewer" : "Växla mellan redigerings- och visningsläge",
    "Pick a notes folder" : "Välj en anteckningsmapp",
    "Set notes folder" : "Ställ in anteckningsmapp",
    "General" : "Allmänt",
    "Display" : "Visning",
    "File extension" : "Filändelse",
    "For new notes" : "För nya anteckningar",
    "Custom file extension" : "Anpassad filändelse",
    "Files" : "Filer",
    "Notes folder" : "Anteckningsmapp",
    "Mobile apps" : "Mobilappar",
    "Shortcuts" : "Kortkommandon",
    "_Delete category \"{category}\" and its {count} note?_::_Delete category \"{category}\" and its {count} notes?_" : ["Ta bort kategorin \"{category}\" och dess {count} anteckning?","Ta bort kategorin \"{category}\" och dess {count} anteckningar?"],
    "Delete category" : "Ta bort kategori",
    "Delete" : "Ta bort",
    "Cancel" : "Avbryt",
    "All notes" : "Alla anteckningar",
    "Categories" : "Kategorier",
    "Rename category" : "Byt namn på kategori",
    "Create a sample note with Markdown" : "Skapa en exempelanteckning med Markdown",
    "No notes yet" : "Inga anteckningar än",
    "Select an image" : "Välj en bild",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Du kan inte välja bilder utanför din anteckningsmapp. Din anteckningsmapp är: {folder}",
    "Wrong image" : "Fel bild",
    "The file was not uploaded. Check your server logs." : "Filen laddades inte upp. Kontrollera dina serverloggar.",
    "Upload image" : "Ladda upp bild",
    "Android" : "Android",
    "iPhone and iPad" : "iPhone och iPad",
    "Rich text editor" : "Redigerare för formaterad text",
    "You can now switch to use the easy to use and distraction free rich text editor. It allows you to edit notes without seeing any Markdown marks." : "Du kan nu använda den lättanvända och störningsfria redigeraren för formaterad text. Där kan du redigera anteckningar utan att se Markdown-markeringarna.",
    "This option can also be changed later on in the Notes app settings." : "Det här alternativet kan också ändras senare i inställningarna för appen Anteckningar.",
    "Keep plain Markdown editor" : "Behåll den vanliga Markdown-redigeraren",
    "Use rich editor" : "Använd redigeraren för formaterad text",
    "Remove from favorites" : "Ta bort från favoriter",
    "Add to favorites" : "Lägg till som favorit",
    "Error while renaming note." : "Det gick inte att byta namn på anteckningen.",
    "Error during preparing note for deletion." : "Det gick inte att förbereda anteckningen för borttagning.",
    "Change category" : "Ändra kategori",
    "Rename" : "Byt namn",
    "Rename note" : "Byt namn på anteckningen",
    "Delete note" : "Ta bort anteckning",
    "Error from Nextcloud server: {msg}" : "Fel från Nextcloud-servern: {msg}",
    "The note has been changed in another session. Please choose which version should be saved." : "Anteckningen har ändrats i en annan session. Välj vilken version som ska sparas.",
    "Use version from server" : "Använd version från servern",
    "Use current version" : "Använd nuvarande version",
    "Empty note" : "Tom anteckning",
    "Write …" : "Skriv …",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Redigera",
    "Exit full screen" : "Avsluta helskärmsläge",
    "Full screen" : "Helskärm",
    "Note is read-only. You cannot change it." : "Anteckningen är skrivskyddad. Du kan inte ändra den.",
    "Save failed. Click to retry." : "Det gick inte att spara. Klicka för att försöka igen.",
    "Update conflict. Click for resolving manually." : "Uppdateringskonflikt. Klicka för att lösa konflikten manuellt.",
    "Sharing is not available right now." : "Delning är inte tillgänglig just nu.",
    "Failed to load the sharing sidebar." : "Det gick inte att läsa in delningspanelen.",
    "Unable to load the selected note for sharing." : "Det gick inte att läsa in den valda anteckningen för delning.",
    "Today" : "Idag",
    "Yesterday" : "Igår",
    "This week" : "Denna vecka",
    "Last week" : "Förra veckan",
    "This month" : "Denna månad",
    "Last month" : "Förra månaden",
    "Search for notes" : "Sök efter anteckningar",
    "Loading …" : "Läser in …",
    "Find in all categories" : "Sök i alla kategorier",
    "Write down your thoughts without any distractions." : "Skriv ner dina tankar utan att bli störd.",
    "Use Markdown markups to style your text." : "Använd Markdown-kod för att formatera texten.",
    "Organize your notes in categories." : "Organisera dina anteckningar i kategorier.",
    "Start writing a note by clicking on “{newnote}”." : "Börja skriva en anteckning genom att klicka på “{newnote}”.",
    "Note not found." : "Anteckningen hittades inte.",
    "Note is locked." : "Anteckningen är låst.",
    "Insufficient storage." : "Otillräckligt utrymme.",
    "See JavaScript console and server log for details." : "Mer information finns i JavaScript-konsolen och serverloggen.",
    "Updating settings has failed." : "Det gick inte att uppdatera inställningarna.",
    "Fetching notes for dashboard has failed." : "Det gick inte att hämta anteckningar till instrumentpanelen.",
    "Fetching notes has failed." : "Det gick inte att hämta anteckningar.",
    "Fetching note {id} has failed." : "Det gick inte att hämta anteckning {id}.",
    "Refreshing note {id} has failed." : "Det gick inte att uppdatera anteckning {id}.",
    "Renaming note {id} has failed." : "Det gick inte att byta namn på anteckning {id}.",
    "Creating new note has failed." : "Det gick inte att skapa en ny anteckning.",
    "Saving note {id} has failed." : "Det gick inte att spara anteckning {id}.",
    "Updating title for note {id} has failed." : "Det gick inte att uppdatera titeln för anteckning {id}.",
    "Undo delete has failed for note {title}." : "Det gick inte att ångra borttagningen av anteckningen {title}.",
    "Deleting note {id} has failed." : "Det gick inte att ta bort anteckning {id}.",
    "Toggling favorite for note {id} has failed." : "Det gick inte att ändra favoritstatus för anteckning {id}.",
    "Updating the note's category has failed. Is the target directory writable?" : "Det gick inte att uppdatera anteckningens kategori. Är målmappen skrivbar?",
    "Updating the category for note {id} has failed." : "Det gick inte att uppdatera kategorin för anteckning {id}.",
    "Renaming category \"{category}\" has failed." : "Det gick inte att byta namn på kategorin \"{category}\".",
    "Deleting category \"{category}\" has failed." : "Det gick inte att ta bort kategorin \"{category}\".",
    "Uncategorized" : "Okategoriserad",
    "Sample note" : "Exempelanteckning",
    "15 January 2021, via Nextcloud Notes" : "15 januari 2021, via Nextcloud Notes",
    "Me, you, and all our friends!" : "Jag, du och alla våra vänner!",
    "Tasks" : "Uppgifter",
    "Write nice todo lists" : "Skriv tydliga uppgiftslistor",
    "Buy Fries" : "Köp pommes frites",
    "Birthdays" : "Födelsedagar",
    "Jen, in three days!" : "Jen, om tre dagar!",
    "Moss, 21.03.1973" : "Moss, 21.03.1973",
    "Roy, 1979" : "Roy, 1979",
    "Review Steps" : "Granskningssteg",
    "Turn PC off" : "Stäng av datorn",
    "Turn PC on" : "Slå på datorn",
    "Then call IT" : "Ring sedan IT",
    "Quotes" : "Citat",
    "Nextcloud, a safe home for all your data" : "Nextcloud, en säker plats för alla dina data",
    "Development Mode" : "Utvecklingsläge",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Det verkar som om appen Anteckningar installerades från en utvecklingskälla. Installera den i stället från den officiella <a href=\"%1$s\">Nextcloud-appbutiken</a>. Följ <a href=\"%2$s\">utvecklarinstruktionerna</a> om du vill bygga appen själv."
},
"nplurals=2; plural=(n != 1);");
