OC.L10N.register(
    "notes",
    {
    "Notes" : "Σημειώσεις",
    "Create new note" : "Δημιουργία νέας σημείωσης",
    "More notes" : "Περισσότερες σημειώσεις",
    "Reading notes from filesystem has failed." : "Η ανάγνωση σημειώσεων από το σύστημα αρχείων απέτυχε.",
    "Error" : "Σφάλμα",
    "New note" : "Νέα σημείωση",
    "Distraction-free notes and writing" : "Σημειώσεις και γραφή χωρίς περισπασμούς",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into apps ([Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios), as well as [3rd-party apps](https://github.com/nextcloud/notes/wiki#3rd-party-clients) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "Η εφαρμογή Σημειώσεις είναι μια εφαρμογή λήψης σημειώσεων χωρίς περισπασμούς για το [Nextcloud](https://www.nextcloud.com/). Παρέχει κατηγορίες για καλύτερη οργάνωση και υποστηρίζει μορφοποίηση χρησιμοποιώντας σύνταξη [Markdown](https://en.wikipedia.org/wiki/Markdown). Οι σημειώσεις αποθηκεύονται ως αρχεία στο Nextcloud σας, ώστε να μπορείτε να τις προβάλλετε και να τις επεξεργαστείτε με κάθε πελάτη Nextcloud. Επιπλέον, ένα ξεχωριστό [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) επιτρέπει την εύκολη ενσωμάτωση σε εφαρμογές ([Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios), καθώς και [εφαρμογές τρίτων ](https://github.com/nextcloud/notes/wiki#3rd-party-clients) που επιτρέπουν εύκολη πρόσβαση στις σημειώσεις σας στο Nextcloud). Περαιτέρω λειτουργίες περιλαμβάνουν τη σήμανση σημειώσεων ως αγαπημένες.",
    "Share" : "Κοινοποίηση",
    "Deleted {title}" : "Διαγράφηκε το {title}",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["Διαγράφηκε {number} σημείωση","Διαγράφηκαν {number} σημειώσεις"],
    "Undo Delete" : "Αναίρεση διαγραφής",
    "Note recovered" : "Η σημείωση ανακτήθηκε",
    "_Recovered {number} note_::_Recovered {number} notes_" : ["Επαναφέρθηκε {number} σημείωση","Επαναφέρθηκαν {number} σημειώσεις"],
    "There are unsaved notes. Leaving the page will discard all changes!" : "Υπάρχουν σημειώσεις που δεν έχουν αποθηκευτεί. Φεύγοντας από τη σελίδα θα απορριφθούν όλες οι αλλαγές!",
    "New category" : "Νέα κατηγορία",
    "Notes settings" : "Ρυθμίσεις σημειώσεων",
    "Please see Nextcloud server log for details." : "Για λεπτομέρειες παρακαλούμε δείτε το καταγραφικό του διακομιστή Nextcloud.",
    "Custom" : "Προσαρμοσμένο",
    "Rich text" : "Μορφοποιημένο κείμενο",
    "Plain text" : "Απλό κείμενο",
    "Preview" : "Προεπισκόπηση",
    "Make the selection bold" : "Μετατροπή της επιλογής σε έντονη γραφή",
    "Make the selection italic" : "Μετατροπή της επιλογής σε πλάγια γραφή",
    "Wrap the selection in quotes" : "Περικλείστε την επιλογή σε εισαγωγικά",
    "The selection will be turned into monospace" : "Η επιλογή θα μετατραπεί σε monospace",
    "Remove any styles from the selected text" : "Αφαίρεση όλων των στυλ από το επιλεγμένο κείμενο",
    "Makes the current line a list element" : "Μετατρέπει την τρέχουσα γραμμή σε στοιχείο λίστας",
    "Makes the current line a list element with a number" : "Μετατρέπει την τρέχουσα γραμμή σε στοιχείο αριθμημένης λίστας",
    "Toggle heading for current line" : "Εναλλαγή επικεφαλίδας για την τρέχουσα γραμμή",
    "Set the current line as a big heading" : "Ορισμός της τρέχουσας γραμμής ως μεγάλης επικεφαλίδας",
    "Insert link" : "Εισαγωγή συνδέσμου",
    "Insert image" : "Εισαγωγή εικόνας",
    "Switch between editor and viewer" : "Εναλλαγή μεταξύ επεξεργαστή και προβολέα",
    "Pick a notes folder" : "Επιλογή φακέλου σημειώσεων",
    "Set notes folder" : "Ορισμός φακέλου σημειώσεων",
    "General" : "Γενικά",
    "Display" : "Εμφάνιση",
    "File extension" : "Επέκταση αρχείου",
    "For new notes" : "Για νέες σημειώσεις",
    "Custom file extension" : "Προσαρμοσμένη επέκταση αρχείου",
    "Files" : "Αρχεία",
    "Notes folder" : "Φάκελος σημειώσεων",
    "Mobile apps" : "Εφαρμογές για φορητές συσκευές",
    "Shortcuts" : "Συντομεύσεις",
    "_Delete category \"{category}\" and its {count} note?_::_Delete category \"{category}\" and its {count} notes?_" : ["Διαγραφή της κατηγορίας \"{category}\" και της {count} σημείωσής της;","Διαγραφή της κατηγορίας \"{category}\" και των {count} σημειώσεών της;"],
    "Delete category" : "Διαγραφή κατηγορίας",
    "Delete" : "Διαγραφή",
    "Cancel" : "Ακύρωση",
    "All notes" : "Όλες οι σημειώσεις",
    "Categories" : "Κατηγορίες",
    "Rename category" : "Μετονομασία κατηγορίας",
    "Create a sample note with Markdown" : "Δημιουργία δείγματος σημείωσης με Markdown",
    "No notes yet" : "Δεν υπάρχουν ακόμα σημειώσεις",
    "Select an image" : "Επιλέξτε μια εικόνα",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Δεν μπορείτε να επιλέξετε εικόνες εκτός του φακέλου σημειώσεων. Ο φάκελος σημειώσεων είναι: {folder}",
    "Wrong image" : "Λανθασμένη εικόνα",
    "The file was not uploaded. Check your server logs." : "Το αρχείο δεν μεταφορτώθηκε. Ελέγξτε τα αρχεία καταγραφής του διακομιστή σας.",
    "Upload image" : "Μεταφόρτωση εικόνας",
    "Android" : "Android",
    "iPhone and iPad" : "iPhone και iPad",
    "Rich text editor" : "Επεξεργαστής εμπλουτισμένου κειμένου",
    "You can now switch to use the easy to use and distraction free rich text editor. It allows you to edit notes without seeing any Markdown marks." : "Μπορείτε τώρα να μεταβείτε στη χρήση του εύχρηστου επεξεργαστή εμπλουτισμένου κειμένου χωρίς περισπασμούς. Σας επιτρέπει να επεξεργάζεστε σημειώσεις χωρίς να βλέπετε συμβόλαια Markdown.",
    "This option can also be changed later on in the Notes app settings." : "Αυτή η επιλογή μπορεί επίσης να αλλάξει αργότερα στις ρυθμίσεις της εφαρμογής Σημειώσεις.",
    "Keep plain Markdown editor" : "Διατήρηση απλού επεξεργαστή Markdown",
    "Use rich editor" : "Χρήση επεξεργαστή εμπλουτισμένου κειμένου",
    "Remove from favorites" : "Αφαίρεση από τα αγαπημένα",
    "Add to favorites" : "Προσθήκη στα αγαπημένα",
    "Error while renaming note." : "Σφάλμα κατά τη μετονομασία της σημείωσης.",
    "Error during preparing note for deletion." : "Σφάλμα κατά την προετοιμασία της σημείωσης για διαγραφή.",
    "Change category" : "Αλλαγή κατηγορίας",
    "Rename" : "Μετονομασία",
    "Rename note" : "Μετονομασία σημείωσης",
    "Delete note" : "Διαγραφή σημείωσης",
    "Error from Nextcloud server: {msg}" : "Σφάλμα από τον διακομιστή Nextcloud: {msg}",
    "The note has been changed in another session. Please choose which version should be saved." : "Η σημείωση έχει τροποποιηθεί σε μια άλλη συνεδρία. Παρακαλούμε επιλέξτε ποια έκδοση πρέπει να αποθηκευτεί.",
    "Use version from server" : "Χρήση της έκδοσης από τον διακομιστή",
    "Use current version" : "Χρήση της τρέχουσας έκδοσης",
    "Empty note" : "Κενή σημείωση",
    "Write …" : "Σύνταξη ...",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Επεξεργασία",
    "Exit full screen" : "Έξοδος από πλήρη οθόνη",
    "Full screen" : "Πλήρης οθόνη",
    "Note is read-only. You cannot change it." : "Η σημείωση είναι μόνο για ανάγνωση. Δεν μπορείτε να την τροποποιήσετε.",
    "Save failed. Click to retry." : "Η αποθήκευση απέτυχε. Κάντε κλικ για να προσπαθήσετε ξανά.",
    "Update conflict. Click for resolving manually." : "Σύγκρουση ενημέρωσης. Κάντε κλικ για χειροκίνητη επίλυση.",
    "Sharing is not available right now." : "Η κοινοποίηση δεν είναι διαθέσιμη αυτή τη στιγμή.",
    "Failed to load the sharing sidebar." : "Αποτυχία φόρτωσης της πλευρικής γραμμής κοινοποίησης.",
    "Unable to load the selected note for sharing." : "Αδυναμία φόρτωσης της επιλεγμένης σημείωσης για κοινοποίηση.",
    "Today" : "Σήμερα",
    "Yesterday" : "Χθες",
    "This week" : "Αυτή την εβδομάδα",
    "Last week" : "Προηγούμενη εβδομάδα",
    "This month" : "Αυτόν τον μήνα",
    "Last month" : "Προηγούμενος μήνας",
    "Search for notes" : "Αναζήτηση σημειώσεων",
    "Loading …" : "Φόρτωση …",
    "Find in all categories" : "Εύρεση σε όλες τις κατηγορίες",
    "Write down your thoughts without any distractions." : "Γράψτε τις σκέψεις σας χωρίς περισπασμούς.",
    "Use Markdown markups to style your text." : "Χρησιμοποιήστε διαμορφώσεις Markdown για να δώσετε στυλ στο κείμενό σας.",
    "Organize your notes in categories." : "Οργανώστε τις σημειώσεις σας σε κατηγορίες.",
    "Start writing a note by clicking on “{newnote}”." : "Ξεκινήστε τη γραφή μιας σημείωσης κάνοντας κλικ στο «{newnote}».",
    "Note not found." : "Η σημείωση δεν βρέθηκε.",
    "Note is locked." : "Η σημείωση είναι κλειδωμένη.",
    "Insufficient storage." : "Ανεπαρκής χώρος αποθήκευσης.",
    "See JavaScript console and server log for details." : "Δείτε την κονσόλα JavaScript και το αρχείο καταγραφής του διακομιστή για λεπτομέρειες.",
    "Updating settings has failed." : "Η ενημέρωση των ρυθμίσεων απέτυχε.",
    "Fetching notes for dashboard has failed." : "Η ανάκτηση σημειώσεων για τον πίνακα ελέγχου απέτυχε.",
    "Fetching notes has failed." : "Η ανάκτηση σημειώσεων απέτυχε.",
    "Fetching note {id} has failed." : "Η ανάκτηση της σημείωσης {id} απέτυχε.",
    "Refreshing note {id} has failed." : "Η ανανέωση της σημείωσης {id} απέτυχε.",
    "Renaming note {id} has failed." : "Η μετονομασία της σημείωσης {id} απέτυχε.",
    "Creating new note has failed." : "Η δημιουργία νέας σημείωσης απέτυχε.",
    "Saving note {id} has failed." : "Η αποθήκευση της σημείωσης {id} απέτυχε.",
    "Updating title for note {id} has failed." : "Η ενημέρωση του τίτλου της σημείωσης {id} απέτυχε.",
    "Undo delete has failed for note {title}." : "Η αναίρεση διαγραφής απέτυχε για τη σημείωση {title}.",
    "Deleting note {id} has failed." : "Η διαγραφή της σημείωσης {id} απέτυχε.",
    "Toggling favorite for note {id} has failed." : "Η εναλλαγή αγαπημένου για τη σημείωση {id} απέτυχε.",
    "Updating the note's category has failed. Is the target directory writable?" : "Η ενημέρωση της κατηγορίας της σημείωσης απέτυχε. Είναι ο κατάλογος προορισμού εγγράψιμος;",
    "Updating the category for note {id} has failed." : "Η ενημέρωση της κατηγορίας για τη σημείωση {id} απέτυχε.",
    "Renaming category \"{category}\" has failed." : "Η μετονομασία της κατηγορίας \"{category}\" απέτυχε.",
    "Deleting category \"{category}\" has failed." : "Η διαγραφή της κατηγορίας \"{category}\" απέτυχε.",
    "Uncategorized" : "Χωρίς κατηγορία",
    "Sample note" : "Δείγμα σημείωσης",
    "15 January 2021, via Nextcloud Notes" : "15 Ιανουαρίου 2021, μέσω Nextcloud Notes",
    "Me, you, and all our friends!" : "Εγώ, εσύ, και όλοι οι φίλοι μας!",
    "Tasks" : "Εργασίες",
    "Write nice todo lists" : "Γράψτε ωραίες λίστες εργασιών",
    "Buy Fries" : "Αγορά πατατών",
    "Birthdays" : "Γενέθλια",
    "Jen, in three days!" : "Jen, σε τρεις μέρες!",
    "Moss, 21.03.1973" : "Moss, 21.03.1973",
    "Roy, 1979" : "Roy, 1979",
    "Review Steps" : "Βήματα επισκόπησης",
    "Turn PC off" : "Απενεργοποίηση υπολογιστή",
    "Turn PC on" : "Ενεργοποίηση υπολογιστή",
    "Then call IT" : "Έπειτα καλέστε το IT",
    "Quotes" : "Παραθέματα",
    "Nextcloud, a safe home for all your data" : "Nextcloud, ένα ασφαλές σπίτι για όλα τα δεδομένα σας",
    "Development Mode" : "Λειτουργία ανάπτυξης",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Φαίνεται ότι η εφαρμογή σημειώσεων εγκαταστάθηκε από μια πηγή ανάπτυξης. Παρακαλούμε εγκαταστήστε την από το επίσημο <a href=\"%1$s\">Κατάστημα Εφαρμογών Nextcloud</a>. Αν επιθυμείτε να δημιουργήσετε την εφαρμογή Σημειώσεις μόνοι σας, παρακαλούμε ακολουθήστε τις <a href=\"%2$s\">οδηγίες προγραμματιστών</a>."
},
"nplurals=2; plural=(n != 1);");
